aboutsummaryrefslogtreecommitdiff
path: root/tests/wsp.c
diff options
context:
space:
mode:
Diffstat (limited to 'tests/wsp.c')
-rw-r--r--tests/wsp.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/wsp.c b/tests/wsp.c
index e8eb9c6..09eb6ba 100644
--- a/tests/wsp.c
+++ b/tests/wsp.c
@@ -1,4 +1,4 @@
/* grecs - Gray's Extensible Configuration System
Copyright (C) 2014-2016 Sergey Poznyakoff
Grecs is free software; you can redistribute it and/or modify it
@@ -22,7 +22,7 @@
#include <string.h>
#include <assert.h>
#include <errno.h>
-#include "grecs.h"
+#include "argot.h"
#include "wordsplit.h"
extern char **environ;
@@ -223,7 +223,7 @@ wsp_runcmd (char **ret, const char *str, size_t len, char **argv, void *closure)
{
size_t size = 0;
ret = NULL;
- if (grecs_asprintf (ret, &size, "can't run %s: %s",
+ if (argot_asprintf (ret, &size, "can't run %s: %s",
cmd, strerror (errno)))
return WRDSE_NOSPACE;
else
@@ -1,4 +1,4 @@
-/* grecs - Gray's Extensible Configuration System
+/* argot - Gray's Extensible Configuration System
Copyright (C) 2014-2016 Sergey Poznyakoff
Grecs is free software; you can redistribute it and/or modify it

Return to:

Send suggestions and report system problems to the System administrator.